from ..querytypes.querytypes import QUERYTYPES
from ..querytypes.const import (QUARTER_HOURLY, QUERYTYPE_BASICMAX)
from dataclasses import dataclass
from ..locale_model import Locale_Type


@dataclass(frozen=True)
class VregBelgium(Locale_Type):
    observed_peak = QUERYTYPE_BASICMAX
    charged_peak = QUERYTYPE_BASICMAX
    query_model = QUERYTYPES[QUERYTYPE_BASICMAX]
    #TODO: to be decided. Should charged_peak be turned into the real charged peak, ie the average of the months in a year? could be issues with the long term stats there and it won't help peaq in any way.
    peak_cycle = QUARTER_HOURLY

#https://www.vreg.be/nl/nieuwe-nettarieven        



from dataclasses import dataclass

@dataclass
class PowerReading:
    price: float
    power: float
    td: float

    @property
    def reading_integral(self):
        return self.power/1000 * (self.td/3600)

    @property
    def reading_cost(self):
        return self.reading_integral * self.price



# from .Threshold import ThresholdBase as Threshold
# from .Chargecontroller import ChargeControllerBase as ChargeController
# from .Prediction import PredictionBase as Prediction
# from .hoursselection import Hoursselectionbase as Hoursselection
# from .session import SessionPrice as Session
# from .locale_service.querytypes import querytypes
# from .locale_service import (Locale, locale_model)
# from .country_service import (belgium, sweden, norway, default)





from ...hub.hub import HubBase
from .chargecontroller import ChargeController
from .chargecontroller_lite import ChargeControllerLite

class ChargeControllerFactory:
    @staticmethod
    def create(hubbase: HubBase):
        if hubbase.hub.peaqtype_is_lite:
            return ChargeControllerLite(hubbase.hub)
        return ChargeController(hubbase.hub)


from ...hub.hub import HubBase
from .threshold import Threshold
from .threshold_lite import ThresholdLite

class ThresholdFactory:
    @staticmethod
    def create(hubbase: HubBase):
        if hubbase.hub.peaqtype_is_lite:
            return ThresholdLite(hubbase.hub)
        return Threshold(hubbase.hub)